============
Core Widgets
============


App
===

.. autoclass:: toga.interface.app.App
   :members:

Widget
======

.. autoclass:: toga.interface.widgets.base.Widget
   :members:

Container
=========

.. autoclass:: toga.interface.widgets.container.Container
   :members:

Button

TextInput

PasswordInput
